Package for transforming a .csv file containing a Ancient Greek - Old Church Slavonic-Latin dictionary into TEI XML. At this moment this package works for that particular .csv file.

As a bonus there is a visualization tool: you can see the average count of old church slavonic equivalents and look into part of speech distribution.

Made as a part of an international project "Epifanii Slavinetskii’s Greek–Slavonic–Latin Lexicon in the East Slavic and European Language Space of the 16th–early 18th Century".